@@ -1,7 +1,7 @@
 package Perinci::Examples::ArgsAs;
 
-our $DATE = '2016-12-10'; # DATE
-our $VERSION = '0.77'; # VERSION
+our $DATE = '2017-01-12'; # DATE
+our $VERSION = '0.78'; # VERSION
 
 use 5.010001;
 use strict;
@@ -100,7 +100,7 @@ Perinci::Examples::ArgsAs - Demonstrate various values of `args_as` function met
 
 =head1 VERSION
 
-This document describes version 0.77 of Perinci::Examples::ArgsAs (from Perl distribution Perinci-Examples), released on 2016-12-10.
+This document describes version 0.78 of Perinci::Examples::ArgsAs (from Perl distribution Perinci-Examples), released on 2017-01-12.
 
 =head1 DESCRIPTION
 
@@ -226,7 +226,7 @@ Examples:
 
 Result:
 
- [200, "OK", ["arg1", "def", "arg3", 0.5, "arg2", 20], {}]
+ [200, "OK", ["arg3", 0.5, "arg2", 20, "arg1", "def"], {}]
 
 =back
 
@@ -325,7 +325,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
