@@ -1,7 +1,7 @@
 package Perinci::Examples::CLI;
 
-our $DATE = '2016-12-10'; # DATE
-our $VERSION = '0.77'; # VERSION
+our $DATE = '2017-01-12'; # DATE
+our $VERSION = '0.78'; # VERSION
 
 use 5.010001;
 use strict;
@@ -323,7 +323,7 @@ Perinci::Examples::CLI - Example for CLI help/usage generation
 
 =head1 VERSION
 
-This document describes version 0.77 of Perinci::Examples::CLI (from Perl distribution Perinci-Examples), released on 2016-12-10.
+This document describes version 0.78 of Perinci::Examples::CLI (from Perl distribution Perinci-Examples), released on 2017-01-12.
 
 =head1 DESCRIPTION
 
@@ -378,11 +378,11 @@ Result:
    {
      logs => [
                {
-                 file    => "/home/s1/perl5/perlbrew/perls/perl-5.24.0/lib/site_perl/5.24.0/Perinci/Access/Schemeless.pm",
+                 file    => "/home/u1/perl5/perlbrew/perls/perl-5.24.0/lib/site_perl/5.24.0/Perinci/Access/Schemeless.pm",
                  func    => "Perinci::Access::Schemeless::action_call",
                  line    => 494,
                  package => "Perinci::Access::Schemeless",
-                 time    => 1481376947,
+                 time    => 1484189666,
                  type    => "create",
                },
              ],
@@ -605,7 +605,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
