@@ -1,7 +1,7 @@
 package Perinci::Examples::ResultNaked;
 
-our $DATE = '2016-12-10'; # DATE
-our $VERSION = '0.77'; # VERSION
+our $DATE = '2017-01-12'; # DATE
+our $VERSION = '0.78'; # VERSION
 
 use 5.010001;
 use strict;
@@ -76,7 +76,7 @@ Perinci::Examples::ResultNaked - Demonstrate `result_naked` property
 
 =head1 VERSION
 
-This document describes version 0.77 of Perinci::Examples::ResultNaked (from Perl distribution Perinci-Examples), released on 2016-12-10.
+This document describes version 0.78 of Perinci::Examples::ResultNaked (from Perl distribution Perinci-Examples), released on 2017-01-12.
 
 =head1 DESCRIPTION
 
@@ -108,7 +108,7 @@ Examples:
 
 =item * With the optional arg3:
 
- result_naked(arg1 => "def", arg2 => 20, arg3 => 0.5); # -> ["arg1", "def", "arg2", 20, "arg3", 0.5]
+ result_naked(arg1 => "def", arg2 => 20, arg3 => 0.5); # -> ["arg1", "def", "arg3", 0.5, "arg2", 20]
 
 =back
 
@@ -147,7 +147,7 @@ Examples:
 
 Result:
 
- [200, "OK", ["arg2", 20, "arg3", 0.5, "arg1", "def"], {}]
+ [200, "OK", ["arg3", 0.5, "arg2", 20, "arg1", "def"], {}]
 
 =back
 
@@ -198,7 +198,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
