@@ -1,7 +1,7 @@
 package Perinci::Examples::Tiny;
 
-our $DATE = '2016-12-10'; # DATE
-our $VERSION = '0.77'; # VERSION
+our $DATE = '2017-01-12'; # DATE
+our $VERSION = '0.78'; # VERSION
 
 our %SPEC;
 
@@ -77,6 +77,40 @@ $SPEC{foo4} = {
 };
 sub foo4 { [200, "OK", "foo4"] }
 
+# this Rinci metadata is already normalized
+$SPEC{sum} = {
+    v => 1.1,
+    summary => "Sum numbers in array",
+    description => <<'_',
+
+This function can be used to test passing nonscalar (array) arguments.
+
+_
+    args => {
+        array => {
+            summary => 'Array',
+            schema  => ['array', {req=>1, of => ['float', {req=>1}, {}]}, {}],
+            req     => 1,
+            pos     => 0,
+            greedy  => 1,
+        },
+        round => {
+            summary => 'Whether to round result to integer',
+            schema  => [bool => {default => 0}, {}],
+        },
+    },
+};
+sub sum {
+    my %args = @_;
+
+    my $sum = 0;
+    for (@{$args{array}}) {
+        $sum += $_ if defined && /\A(?:\d+(?:\.\d*)?|\.\d+)\z/;
+    }
+    $sum = int($sum) if $args{round};
+    [200, "OK", $sum];
+}
+
 1;
 # ABSTRACT: Small examples
 
@@ -92,7 +126,7 @@ Perinci::Examples::Tiny - Small examples
 
 =head1 VERSION
 
-This document describes version 0.77 of Perinci::Examples::Tiny (from Perl distribution Perinci-Examples), released on 2016-12-10.
+This document describes version 0.78 of Perinci::Examples::Tiny (from Perl distribution Perinci-Examples), released on 2017-01-12.
 
 =head1 DESCRIPTION
 
@@ -240,6 +274,40 @@ that contains extra information.
 
 Return value:  (str)
 
+
+=head2 sum(%args) -> [status, msg, result, meta]
+
+Sum numbers in array.
+
+This function can be used to test passing nonscalar (array) arguments.
+
+This function is not exported.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<array>* => I<array[float]>
+
+Array.
+
+=item * B<round> => I<bool> (default: 0)
+
+Whether to round result to integer.
+
+=back
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (any)
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Examples>.
@@ -262,7 +330,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
